@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::AutoRoute;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -38,7 +38,7 @@ sub register {
   # Index
   $r->route('/')
     ->over($condition_name)
-    ->to(cb => sub { shift->render("/$top_dir/index") });
+    ->to(cb => sub { shift->render("/$top_dir/index", 'mojo.maybe' => 1) });
   
   # Route
   $r->route('/(*__auto_route_plugin_path)')
@@ -48,8 +48,18 @@ sub register {
       
       my $path = $c->stash('__auto_route_plugin_path');
       
-      $c->render("/$top_dir/$path");
+      $c->render("/$top_dir/$path", 'mojo.maybe' => 1);
     });
+  
+  # Finish rendering Helper
+  $app->helper(finish_rendering => sub {
+    my $self = shift;
+    
+    $self->stash->{'mojo.routed'} = 1;
+    $self->rendered;
+    
+    return $self;
+  });
 }
 
 1;
@@ -60,7 +70,7 @@ Mojolicious::Plugin::AutoRoute - Mojolicious Plugin to create routes automatical
 
 =head1 CAUTION
 
-B<This is beta release. Implementation will be changed without warnings>. 
+B<This is beta release and very experimental. Implementation will be changed without warnings>. 
 
 =head1 SYNOPSIS
 
@@ -86,9 +96,41 @@ Routes corresponding to URL is created .
 If you like C<PHP>, this plugin is very good.
 You only put file into C<auto> directory.
 
+=head1 EXAMPLE
+
+  use Mojolicious::Lite;
+  
+  # AutoRoute
+  plugin 'AutoRoute';
+  
+  # Custom routes
+  get '/create/:id' => template '/create';
+  
+  @@ auto/index.html.ep
+  /
+  
+  @@ auto/foo.html.ep
+  /foo
+  
+  @@ auto/bar.html.ep
+  /bar
+  
+  @@ auto/foo/bar/baz.html.ep
+  /foo/bar/baz
+  
+  @@ auto/json.html.ep
+  <%
+    $self->render(json => {foo => 1});
+    $self->finish_rendering;
+    return;
+  %>
+  
+  @@ create.html.ep
+  /create/<%= $id %>
+
 =head1 OPTIONS
 
-=head2 C<route>
+=head2 route
 
   route => $route;
 
@@ -96,18 +138,56 @@ You can set parent route if you need.
 This is L<Mojolicious::Routes> object.
 Default is C<$app->routes>.
 
-=head2 C<top_dir>
+=head2 top_dir
 
   top_dir => 'myauto'
 
 Top directory. default is C<auto>.
 
-=head1 METHODS
+=head1 HELPER
 
-L<Mojolicious::Plugin::AutoRoute> inherits all methods from
-L<Mojolicious::Plugin> and implements the following new ones.
+=head2 finish_rendering
 
-=head2 C<register>
+You can render data, json, not found and exeption from template
+using C<finish_rendering> helper.
+
+  @@ index.html.ep
+  $self->render(data => 'foo');
+  $self->finish_rendering;
+  return;
+
+  @@ index.html.ep
+  $self->render(json => {foo => 1});
+  $self->finish_rendering;
+  return;
+
+  @@ index.html.ep
+  $self->render_not_found;
+  $self->finish_rendering;
+  return;
+
+  @@ index.html.ep
+  $self->render_exception;
+  $self->finish_rendering;
+  return;
+
+=head1 FUNCTIONS
+
+=head2 template(Mojolicious::Plugin::AutoRoute::Util)
+
+If you want to create custom route, use C<template> function.
+
+  use Mojolicious::Plugin::AutoRoute::Util 'template';
+  
+  # Mojolicious Lite
+  get '/foo' => template '/foo';
+
+  # Mojolicious
+  $r->get('/foo' => template '/foo');
+
+C<template> is return callback to call C<render_maybe>.
+
+=head2 register
 
   $plugin->register($app);
 
